Package 'rk.googlesheets4'

Title: An RKWard plugin package for google sheet manipulation using the 'googlesheets4' library.
Description: An RKWard plugin package for google sheet manipulation using the 'googlesheets4' library.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.0.2
Built: 2026-05-24 05:44:23 UTC
Source: https://github.com/AlfCano/rk.googlesheets4

Help Index